==> igniteui-react-layouts-18.7.4.tgz: package/esm5/lib/igr-tool-action-icon-menu.js <==
import { __extends } from "tslib";
import { IgrToolActionIconButton } from "./igr-tool-action-icon-button";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { brushToString, stringToBrush, ensureBool } from "igniteui-react-core";
var IgrToolActionIconMenu = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionIconMenu, _super);
    function IgrToolActionIconMenu(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionIconMenu.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgrToolActionIconMenu.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jv);
        },
        set: function (v) {
            this.i.jv = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.ju);
        },
        set: function (v) {
            this.i.ju = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.jh;
        },
        set: function (v) {
            this.i.jh = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionIconMenu.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    return IgrToolActionIconMenu;
}(IgrToolActionIconButton));
export { IgrToolActionIconMenu };

==> igniteui-react-layouts-18.7.6.tgz: package/esm5/lib/igr-tool-action-icon-menu.js <==
import { __extends } from "tslib";
import { IgrToolActionIconButton } from "./igr-tool-action-icon-button";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { brushToString, stringToBrush, ensureBool } from "igniteui-react-core";
var IgrToolActionIconMenu = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionIconMenu, _super);
    function IgrToolActionIconMenu(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionIconMenu.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgrToolActionIconMenu.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jw);
        },
        set: function (v) {
            this.i.jw = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jv);
        },
        set: function (v) {
            this.i.jv = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionIconMenu.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.jk;
        },
        set: function (v) {
            this.i.jk = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrToolActionIconMenu.prototype.exportVisualData = function () {
        var iv = this.i.cm();
        return (iv);
    };
    return IgrToolActionIconMenu;
}(IgrToolActionIconButton));
export { IgrToolActionIconMenu };
